EXPORTS
	?fetchContacts@MsgUiUtilsManager@@QAEXXZ @ 1 NONAME ; void MsgUiUtilsManager::fetchContacts(void)
	?activateInputBlocker@MsgUiUtilsManager@@QAEXPAVQGraphicsWidget@@@Z @ 2 NONAME ; void MsgUiUtilsManager::activateInputBlocker(class QGraphicsWidget *)
	?saveToDrafts@MsgUiUtilsManager@@QAEJAAVConvergedMessage@@@Z @ 3 NONAME ; long MsgUiUtilsManager::saveToDrafts(class ConvergedMessage &)
	?fetchVideo@MsgUiUtilsManager@@QAEXXZ @ 4 NONAME ; void MsgUiUtilsManager::fetchVideo(void)
	??0MsgUiUtilsManager@@QAE@PAVQObject@@@Z @ 5 NONAME ; MsgUiUtilsManager::MsgUiUtilsManager(class QObject *)
	?metaObject@MsgUiUtilsManager@@UBEPBUQMetaObject@@XZ @ 6 NONAME ; struct QMetaObject const * MsgUiUtilsManager::metaObject(void) const
	?send@MsgUiUtilsManager@@QAEHAAVConvergedMessage@@@Z @ 7 NONAME ; int MsgUiUtilsManager::send(class ConvergedMessage &)
	??_EMsgUiUtilsManager@@UAE@I@Z @ 8 NONAME ; MsgUiUtilsManager::~MsgUiUtilsManager(unsigned int)
	?matchDigits@MatchPhNumberUtil@@SAHXZ @ 9 NONAME ; int MatchPhNumberUtil::matchDigits(void)
	?audiosFetched@MsgUiUtilsManager@@IAEXABVQVariant@@@Z @ 10 NONAME ; void MsgUiUtilsManager::audiosFetched(class QVariant const &)
	?openContactDetails@MsgUiUtilsManager@@QAEXH@Z @ 11 NONAME ; void MsgUiUtilsManager::openContactDetails(int)
	?staticMetaObject@MsgUiUtilsManager@@2UQMetaObject@@B @ 12 NONAME ; struct QMetaObject const MsgUiUtilsManager::staticMetaObject
	?fetchImages@MsgUiUtilsManager@@QAEXXZ @ 13 NONAME ; void MsgUiUtilsManager::fetchImages(void)
	?contactsFetched@MsgUiUtilsManager@@IAEXABVQVariant@@@Z @ 14 NONAME ; void MsgUiUtilsManager::contactsFetched(class QVariant const &)
	?trUtf8@MsgUiUtilsManager@@SA?AVQString@@PBD0H@Z @ 15 NONAME ; class QString MsgUiUtilsManager::trUtf8(char const *, char const *, int)
	?fetchAudio@MsgUiUtilsManager@@QAEXXZ @ 16 NONAME ; void MsgUiUtilsManager::fetchAudio(void)
	?tr@MsgUiUtilsManager@@SA?AVQString@@PBD0@Z @ 17 NONAME ; class QString MsgUiUtilsManager::tr(char const *, char const *)
	?getStaticMetaObject@MsgUiUtilsManager@@SAABUQMetaObject@@XZ @ 18 NONAME ; struct QMetaObject const & MsgUiUtilsManager::getStaticMetaObject(void)
	?imagesFetched@MsgUiUtilsManager@@IAEXABVQVariant@@@Z @ 19 NONAME ; void MsgUiUtilsManager::imagesFetched(class QVariant const &)
	?qt_metacast@MsgUiUtilsManager@@UAEPAXPBD@Z @ 20 NONAME ; void * MsgUiUtilsManager::qt_metacast(char const *)
	?fetchOther@MsgUiUtilsManager@@QAEXXZ @ 21 NONAME ; void MsgUiUtilsManager::fetchOther(void)
	?serviceError@MsgUiUtilsManager@@IAEXABVQString@@@Z @ 22 NONAME ; void MsgUiUtilsManager::serviceError(class QString const &)
	?deactivateInputBlocker@MsgUiUtilsManager@@QAEXXZ @ 23 NONAME ; void MsgUiUtilsManager::deactivateInputBlocker(void)
	?qt_metacall@MsgUiUtilsManager@@UAEHW4Call@QMetaObject@@HPAPAX@Z @ 24 NONAME ; int MsgUiUtilsManager::qt_metacall(enum QMetaObject::Call, int, void * *)
	?tr@MsgUiUtilsManager@@SA?AVQString@@PBD0H@Z @ 25 NONAME ; class QString MsgUiUtilsManager::tr(char const *, char const *, int)
	??1MsgUiUtilsManager@@UAE@XZ @ 26 NONAME ; MsgUiUtilsManager::~MsgUiUtilsManager(void)
	?trUtf8@MsgUiUtilsManager@@SA?AVQString@@PBD0@Z @ 27 NONAME ; class QString MsgUiUtilsManager::trUtf8(char const *, char const *)

